import request from '@/utils/request'

// 查询环保信用评价结果的通知列表
export function listNotification(query) {
  return request({
    url: '/crmEnvironmentalCreditEvaluationNotification/findByPage',
    method: 'get',
    params: query
  })
}

// 查询环保信用评价结果的通知详细
export function getNotification(id) {
  return request({
    url: '/basicData/notification/' + id,
    method: 'get'
  })
}

// 新增环保信用评价结果的通知
export function addNotification(data) {
  return request({
    url: '/basicData/notification',
    method: 'post',
    data: data
  })
}

// 修改环保信用评价结果的通知
export function updateNotification(data) {
  return request({
    url: '/basicData/notification',
    method: 'put',
    data: data
  })
}

// 删除环保信用评价结果的通知
export function delNotification(id) {
  return request({
    url: '/crmEnvironmentalCreditEvaluationNotification/deleteAll',
    method: 'delete'
  })
}
// 批量删除行政许可
export function delNotificationBatch(ids) {
  console.log(ids);
  return request.post('/crmEnvironmentalCreditEvaluationNotification/delete',ids)
}
