<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="统一社会信用代码" label-width="200" prop="unifiedSocialCreditCode">
        <el-input
            v-model="queryParams.unifiedSocialCreditCode"
            placeholder="请输入统一社会信用代码"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
      <el-form-item label="公司名称" prop="companyName">
        <el-input
            v-model="queryParams.companyName"
            placeholder="请输入公司名称"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="环保信用评级" prop="creditRating">-->
<!--        <el-input-->
<!--            v-model="queryParams.creditRating"-->
<!--            placeholder="请输入环保信用评级"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="评价时间" prop="evaluationTime">-->
<!--        <el-date-picker clearable-->
<!--                        v-model="queryParams.evaluationTime"-->
<!--                        type="date"-->
<!--                        value-format="YYYY-MM-DD"-->
<!--                        placeholder="请选择评价时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
<!--      <el-form-item label="所属年度" prop="fiscalYear">-->
<!--        <el-input-->
<!--            v-model="queryParams.fiscalYear"-->
<!--            placeholder="请输入所属年度"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="环保信用评分" prop="creditScore">-->
<!--        <el-input-->
<!--            v-model="queryParams.creditScore"-->
<!--            placeholder="请输入环保信用评分"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
      <el-form-item>
        <el-row :gutter="10" class="mb8">
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="primary"-->
          <!--            plain-->
          <!--            icon="Plus"-->
          <!--            @click="handleAdd"-->
          <!--            v-hasPermi="['basicData:notification:add']"-->
          <!--        >新增</el-button>-->
          <!--      </el-col>-->
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="success"-->
          <!--            plain-->
          <!--            icon="Edit"-->
          <!--            :disabled="single"-->
          <!--            @click="handleUpdate"-->
          <!--            v-hasPermi="['basicData:notification:edit']"-->
          <!--        >修改</el-button>-->
          <!--      </el-col>-->
          <el-col :span="1.5">
            <el-popconfirm
                title="你确定清除所有数据？"
                confirm-button-text="是的"
                cancel-button-text="不是"
                :icon="InfoFilled"
                icon-color="#626AEF"
                @confirm="handleDelete"
            >
              <template #reference>
                <el-button
                    type="danger"
                    plain
                    icon="Delete"
                    v-hasPermi="['basicData:license:remove']"
                >清除全表</el-button>
              </template>
            </el-popconfirm>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="danger"
                plain
                icon="Delete"
                @click="batchDelete"
                v-hasPermi="['basicData:license:remove']"
                :disabled="ids.length === 0"
            >批量删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="warning"
                plain
                icon="Download"
                :disabled="!notificationList.length"
                @click="handleExport"
                v-hasPermi="['basicData:notification:export']"
            >导出</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="info" plain icon="Upload" @click="handleImport"
                       v-hasPermi="['system:user:import']">导入
            </el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Download" @click="downloadTemplate">
              下载导入模版
            </el-button>
          </el-col>
          <!--      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>-->
        </el-row>
      </el-form-item>
    </el-form>



    <el-table v-loading="loading" :data="notificationList" height="650" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="主键" align="center" prop="id" />-->
      <el-table-column label="统一社会信用代码" align="center" prop="unifiedSocialCreditCode" width="200" />
      <el-table-column label="公司名称" align="center" prop="companyName" :show-overflow-tooltip='true' />
      <el-table-column label="环保信用评级" align="center" prop="creditRating" :show-overflow-tooltip='true' />
      <el-table-column label="评价时间" align="center" prop="evaluationTime" width="180" :show-overflow-tooltip='true'>
        <template #default="scope">
          <span>{{ parseTime(scope.row.evaluationTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="所属年度" align="center" prop="fiscalYear" :show-overflow-tooltip='true' />
      <el-table-column label="环保信用评分" align="center" prop="creditScore" :show-overflow-tooltip='true' />
<!--      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">-->
<!--        <template #default="scope">-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Edit"-->
<!--              @click="handleUpdate(scope.row)"-->
<!--              v-hasPermi="['basicData:notification:edit']"-->
<!--          >修改</el-button>-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Delete"-->
<!--              @click="handleDelete(scope.row)"-->
<!--              v-hasPermi="['basicData:notification:remove']"-->
<!--          >删除</el-button>-->
<!--        </template>-->
<!--      </el-table-column>-->
    </el-table>

    <div style="position: fixed;bottom: 20px;right: 10px;">
      <pagination
          v-show="total>0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
      />
    </div>

    <el-dialog :title="upload.title" v-model="upload.open" width="400px" append-to-body>
      <el-upload ref="uploadRef" :limit="1" accept=".xlsx, .xls" :headers="upload.headers"
                 :action="upload.url + '?updateSupport=' + upload.updateSupport" :disabled="upload.isUploading"
                 :on-progress="handleFileUploadProgress" :on-success="handleFileSuccess" :auto-upload="false" drag>
        <el-icon class="el-icon--upload"><upload-filled /></el-icon>
        <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        <template #tip>
          <div class="el-upload__tip text-center">
            <span>仅允许导入xls、xlsx格式文件。</span>
          </div>
        </template>
      </el-upload>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitFileForm">确 定</el-button>
          <el-button @click="upload.open = false">取 消</el-button>
        </div>
      </template>
    </el-dialog>

    <!-- 添加或修改环保信用评价结果的通知对话框 -->
    <el-dialog :title="title" v-model="open" width="500px" append-to-body>
      <el-form ref="notificationRef" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="统一社会信用代码" prop="unifiedSocialCreditCode">
          <el-input v-model="form.unifiedSocialCreditCode" placeholder="请输入统一社会信用代码" />
        </el-form-item>
        <el-form-item label="公司名称" prop="companyName">
          <el-input v-model="form.companyName" placeholder="请输入公司名称" />
        </el-form-item>
        <el-form-item label="环保信用评级" prop="creditRating">
          <el-input v-model="form.creditRating" placeholder="请输入环保信用评级" />
        </el-form-item>
        <el-form-item label="评价时间" prop="evaluationTime">
          <el-date-picker clearable
                          v-model="form.evaluationTime"
                          type="date"
                          value-format="YYYY-MM-DD"
                          placeholder="请选择评价时间">
          </el-date-picker>
        </el-form-item>
        <el-form-item label="所属年度" prop="fiscalYear">
          <el-input v-model="form.fiscalYear" placeholder="请输入所属年度" />
        </el-form-item>
        <el-form-item label="环保信用评分" prop="creditScore">
          <el-input v-model="form.creditScore" placeholder="请输入环保信用评分" />
        </el-form-item>
      </el-form>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitForm">确 定</el-button>
          <el-button @click="cancel">取 消</el-button>
        </div>
      </template>
    </el-dialog>
  </div>
</template>

<script setup name="Notification">
import {
  listNotification,
  getNotification,
  delNotification,
  addNotification,
  updateNotification,
  delNotificationBatch
} from "@/api/basicData/notification";
import {reactive} from "vue";
import {getToken} from "@/utils/auth";
import {ElMessage} from "element-plus";
import {likeQueryMethod} from "@/utils/likeQueryMethod";

const { proxy } = getCurrentInstance();

const notificationList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const upload = reactive({
  // 是否显示弹出层（用户导入）
  open: false,
  // 弹出层标题（用户导入）
  title: '',
  // 是否禁用上传
  isUploading: false,
  // 设置上传的请求头部
  headers: {Authorization: getToken()},
  // 上传的地址
  url: import.meta.env.VITE_APP_BASE_API + '/crmEnvironmentalCreditEvaluationNotification/importData'
})
const handleFileSuccess = (e)=>{
  if(e.code == 200){
    ElMessage({
      type:"success",
      message:e.msg
    })
    getList()
    proxy.$refs['uploadRef']?.clearFiles()
  }else {
    ElMessage({
      type:"error",
      message:e.msg
    })
    proxy.$refs['uploadRef']?.clearFiles()
  }
}
function submitFileForm() {
  proxy.$refs['uploadRef'].submit()
  upload.open = false;
  // setTimeout(getList,1000)
}
function handleImport() {
  upload.open = true
  // let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,"company_name",queryParams.value.companyName);
  // listNotification(toServerObj).then(res=>{
  //   if(res.records.length >0){
  //     ElMessage({
  //       type:'warning',
  //       message:'当前已经有数据，请删除后再导入'
  //     })
  //     return
  //   }else {
  //     upload.title = '用户导入'
  //     upload.open = true
  //   }
  // })
}


const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 20,
    unifiedSocialCreditCode: '',
    companyName: null,
    creditRating: null,
    evaluationTime: null,
    fiscalYear: null,
    creditScore: null,
  },
  rules: {
  }
});

const { queryParams, form, rules } = toRefs(data);

/** 查询环保信用评价结果的通知列表 */
function getList() {
  loading.value = true;
  let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,"company_name",queryParams.value.companyName);
  listNotification(toServerObj).then(response => {
    notificationList.value = response.records;
    total.value = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    unifiedSocialCreditCode: '',
    companyName: null,
    creditRating: null,
    evaluationTime: null,
    fiscalYear: null,
    creditScore: null,
    createTime: null,
    updateTime: null
  };
  proxy.resetForm("notificationRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加环保信用评价结果的通知";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const id = row.id || ids.value
  getNotification(id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改环保信用评价结果的通知";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["notificationRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateNotification(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addNotification(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
async function handleDelete(row) {
  const res = await delNotification();
  if(res.code == 200){
    ElMessage({
      type:'success',
      message:'删除成功'
    })
    getList();
  }
  // const ids = row.id || ids.value;
  // proxy.$modal.confirm('是否确认删除环保信用评价结果的通知编号为"' + ids + '"的数据项？').then(function() {
  //   return delNotification(ids);
  // }).then(() => {
  //   getList();
  //   proxy.$modal.msgSuccess("删除成功");
  // }).catch(() => {});
}
/**
 * 批量删除
 */
const batchDelete = (row)=>{
  const idsToS = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除这'+idsToS.length+'条的数据项？').then(function() {
    return delNotificationBatch(toRaw(idsToS));
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('crmEnvironmentalCreditEvaluationNotification/exportData', {
    ...queryParams.value
  }, `环保信用评价导出_${new Date().getTime()}.xlsx`)
}
const downloadTemplate = ()=>{
  proxy.download('crmEnvironmentalCreditEvaluationNotification/getUploadTemplate',{}, `环保信用评价模板.xlsx`)
}

getList();
</script>
